@@ -1,16 +1,17 @@
-from typing import List
-
-from pychromecast import Chromecast
+from __future__ import annotations
 
 from mpris_server.adapters import Metadata, PlayState, MprisAdapter, \
   Microseconds, VolumeDecimal, RateDecimal, PlayerAdapter, RootAdapter
 from mpris_server.base import URI, MIME_TYPES, DEFAULT_RATE, DbusObj, \
   Track
 
-from .wrapper import DeviceWrapper
+from .base import Device
+from .types import Protocol, runtime_checkable
+from .device.wrapper import DeviceWrapper
 
 
-class WrapperIntegration:
+@runtime_checkable
+class DeviceIntegration(Protocol):
   wrapper: DeviceWrapper
 
   def set_icon(self, light_icon: bool):
@@ -20,11 +21,11 @@ class WrapperIntegration:
     self.wrapper.on_new_status(*args, **kwargs)
 
 
-class DeviceRootAdapter(WrapperIntegration, RootAdapter):
-  def get_uri_schemes(self) -> List[str]:
+class DeviceRootAdapter(DeviceIntegration, RootAdapter):
+  def get_uri_schemes(self) -> list[str]:
     return URI
 
-  def get_mime_types(self) -> List[str]:
+  def get_mime_types(self) -> list[str]:
     return MIME_TYPES
 
   def get_desktop_entry(self) -> str:
@@ -37,7 +38,19 @@ class DeviceRootAdapter(WrapperIntegration, RootAdapter):
     self.wrapper.quit()
 
 
-class DevicePlayerAdapter(WrapperIntegration, PlayerAdapter):
+class DevicePlayerAdapter(DeviceIntegration, PlayerAdapter):
+  def metadata(self) -> Metadata:
+    return self.wrapper.metadata()
+
+  def is_repeating(self) -> bool:
+    return self.wrapper.is_repeating()
+
+  def is_playlist(self) -> bool:
+    return self.wrapper.is_playlist()
+
+  def is_mute(self) -> bool:
+    return self.wrapper.is_mute()
+
   def can_go_next(self) -> bool:
     return self.wrapper.can_play_next()
 
@@ -56,6 +69,12 @@ class DevicePlayerAdapter(WrapperIntegration, PlayerAdapter):
   def can_control(self) -> bool:
     return self.wrapper.can_control()
 
+  def can_edit_track(self) -> bool:
+    return self.wrapper.can_edit_track()
+
+  def get_playstate(self) -> PlayState:
+    return self.wrapper.get_playstate()
+
   def get_current_position(self) -> Microseconds:
     return self.wrapper.get_current_position()
 
@@ -77,33 +96,19 @@ class DevicePlayerAdapter(WrapperIntegration, PlayerAdapter):
   def play(self):
     self.wrapper.play()
 
-  def get_playstate(self) -> PlayState:
-    return self.wrapper.get_playstate()
-
-  def seek(self, time: Microseconds):
+  def seek(
+    self,
+    time: Microseconds,
+    track_id: Optional[DbusObj] = None
+  ):
     self.wrapper.seek(time)
 
   def open_uri(self, uri: str):
     self.wrapper.open_uri(uri)
 
-  def is_repeating(self) -> bool:
-    return self.wrapper.is_repeating()
-
-  def is_playlist(self) -> bool:
-    return self.wrapper.is_playlist()
-
   def get_rate(self) -> RateDecimal:
     return self.wrapper.get_rate()
 
-  def set_rate(self, val: RateDecimal):
-    pass
-
-  def get_shuffle(self) -> bool:
-    return False
-
-  def set_shuffle(self, val: bool):
-    pass
-
   def get_art_url(self, track: int = None) -> str:
     return self.wrapper.get_art_url(track)
 
@@ -113,9 +118,6 @@ class DevicePlayerAdapter(WrapperIntegration, PlayerAdapter):
   def set_volume(self, val: VolumeDecimal):
     self.wrapper.set_volume(val)
 
-  def is_mute(self) -> bool:
-    return self.wrapper.is_mute()
-
   def set_mute(self, val: bool):
     self.wrapper.set_mute(val)
 
@@ -125,9 +127,6 @@ class DevicePlayerAdapter(WrapperIntegration, PlayerAdapter):
   def get_duration(self) -> Microseconds:
     return self.wrapper.get_duration()
 
-  def metadata(self) -> Metadata:
-    return self.wrapper.metadata()
-
   def get_current_track(self) -> Track:
     return self.wrapper.get_current_track()
 
@@ -139,8 +138,14 @@ class DevicePlayerAdapter(WrapperIntegration, PlayerAdapter):
   ):
     self.wrapper.add_track(uri, after_track, set_as_current)
 
-  def can_edit_track(self) -> bool:
-    return self.wrapper.can_edit_track()
+  def get_shuffle(self) -> bool:
+    return False
+
+  def set_shuffle(self, val: bool):
+    pass
+
+  def set_rate(self, val: RateDecimal):
+    pass
 
   def set_repeating(self, val: bool):
     pass
@@ -160,6 +165,6 @@ class DeviceAdapter(
   DevicePlayerAdapter,
   DeviceRootAdapter,
 ):
-  def __init__(self, device: Chromecast):
+  def __init__(self, device: Device):
     self.wrapper = DeviceWrapper(device)
     super().__init__(self.wrapper.name)
